@@ -15,38 +15,23 @@
  * limitations under the License.
  */
 
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-
 package org.apache.hertzbeat.alert.service;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import java.util.HashMap;
+
+import com.github.benmanes.caffeine.cache.Cache;
+import org.antlr.v4.runtime.CommonTokenStream;
+import org.antlr.v4.runtime.tree.ParseTree;
 import org.apache.hertzbeat.alert.service.impl.DataSourceServiceImpl;
+import org.apache.hertzbeat.warehouse.db.QueryExecutor;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import java.util.List;
 import java.util.Map;
 import org.mockito.Mockito;
-import org.apache.hertzbeat.warehouse.db.QueryExecutor;
 
 /**
  * test case for {@link DataSourceService}
@@ -544,4 +529,91 @@ class DataSourceServiceTest {
         assertEquals(1, result.size());
         assertEquals(200.0, result.get(0).get("__value__"));
     }
+
+    @Test
+    void expressionCacheShouldHitForSameExpression() {
+        List<Map<String, Object>> prometheusData = List.of(
+                new HashMap<>(Map.of("__value__", 200.0, "timestamp", 1343555, "instance", "node2"))
+        );
+        QueryExecutor mockExecutor = Mockito.mock(QueryExecutor.class);
+        Mockito.when(mockExecutor.support("promql")).thenReturn(true);
+        Mockito.when(mockExecutor.execute(Mockito.anyString())).thenReturn(prometheusData);
+        dataSourceService.setExecutors(List.of(mockExecutor));
+        String expr = "node_cpu_seconds_total > 50";
+        Cache<String, ParseTree> expressionCache = dataSourceService.getExpressionCache();
+        expressionCache.invalidateAll();
+        long beforeHits = expressionCache.stats().hitCount();
+        dataSourceService.calculate("promql", expr); //first execution miss cache
+        dataSourceService.calculate("promql", expr); //second execution hits cache
+        long actualHits = expressionCache.stats().hitCount() - beforeHits;
+        assertEquals(1, actualHits, "expression cache should hit but miss");
+    }
+
+    @Test
+    void tokenCacheShouldHitForSameExpression() {
+        List<Map<String, Object>> prometheusData = List.of(
+                new HashMap<>(Map.of("__value__", 200.0, "timestamp", 1343555, "instance", "node2"))
+        );
+        QueryExecutor mockExecutor = Mockito.mock(QueryExecutor.class);
+        Mockito.when(mockExecutor.support("promql")).thenReturn(true);
+        Mockito.when(mockExecutor.execute(Mockito.anyString())).thenReturn(prometheusData);
+        dataSourceService.setExecutors(List.of(mockExecutor));
+        String expr = "node_cpu_seconds_total > 50";
+        Cache<String, ParseTree> expressionCache = dataSourceService.getExpressionCache();
+        Cache<String, CommonTokenStream> tokenStreamCache = dataSourceService.getTokenStreamCache();
+        expressionCache.invalidateAll();
+        tokenStreamCache.invalidateAll();
+        long beforeHits = tokenStreamCache.stats().hitCount();
+        dataSourceService.calculate("promql", expr);
+        expressionCache.invalidateAll();
+        dataSourceService.calculate("promql", expr);
+        long actualHits = tokenStreamCache.stats().hitCount() - beforeHits;
+        assertEquals(1, actualHits, "expression cache should hit but miss");
+    }
+
+    @Test
+    void expressCacheShouldNotHitForDifferentExpressions() {
+        List<Map<String, Object>> prometheusData = List.of(
+                new HashMap<>(Map.of("__value__", 200.0, "timestamp", 1343555, "instance", "node2"))
+        );
+        QueryExecutor mockExecutor = Mockito.mock(QueryExecutor.class);
+        Mockito.when(mockExecutor.support("promql")).thenReturn(true);
+        Mockito.when(mockExecutor.execute(Mockito.anyString())).thenReturn(prometheusData);
+        dataSourceService.setExecutors(List.of(mockExecutor));
+        dataSourceService.calculate("promql", "node_cpu_seconds_total > 50");
+        Cache<String, ParseTree> expressionCache = dataSourceService.getExpressionCache();
+        Cache<String, CommonTokenStream> tokenStreamCache = dataSourceService.getTokenStreamCache();
+        expressionCache.invalidateAll();
+        tokenStreamCache.invalidateAll();
+        String expr1 = "node_cpu_seconds_total > 30";
+        String expr2 = "node_cpu_seconds_total > 50";
+        long beforeHits = expressionCache.stats().hitCount();
+        dataSourceService.calculate("promql", expr1);
+        dataSourceService.calculate("promql", expr2);
+        long actualHits = expressionCache.stats().hitCount() - beforeHits;
+        assertEquals(0, actualHits, "expression cache should miss but hit");
+    }
+
+    @Test
+    void tokenCacheShouldNotHitForDifferentExpressions() {
+        List<Map<String, Object>> prometheusData = List.of(
+                new HashMap<>(Map.of("__value__", 200.0, "timestamp", 1343555, "instance", "node2"))
+        );
+        QueryExecutor mockExecutor = Mockito.mock(QueryExecutor.class);
+        Mockito.when(mockExecutor.support("promql")).thenReturn(true);
+        Mockito.when(mockExecutor.execute(Mockito.anyString())).thenReturn(prometheusData);
+        dataSourceService.setExecutors(List.of(mockExecutor));
+        dataSourceService.calculate("promql", "node_cpu_seconds_total > 50");
+        Cache<String, ParseTree> expressionCache = dataSourceService.getExpressionCache();
+        Cache<String, CommonTokenStream> tokenStreamCache = dataSourceService.getTokenStreamCache();
+        expressionCache.invalidateAll();
+        tokenStreamCache.invalidateAll();
+        String expr1 = "node_cpu_seconds_total > 30";
+        String expr2 = "node_cpu_seconds_total > 50";
+        long beforeHits = tokenStreamCache.stats().hitCount();
+        dataSourceService.calculate("promql", expr1);
+        dataSourceService.calculate("promql", expr2);
+        long actualHits = tokenStreamCache.stats().hitCount() - beforeHits;
+        assertEquals(0, actualHits, "expression cache should miss but hit");
+    }
 }
