@@ -18,11 +18,14 @@
 package org.apache.hertzbeat.collector.collect.http;
 
 import static org.apache.hertzbeat.common.constants.SignConstants.RIGHT_DASH;
+
 import com.google.gson.JsonArray;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonParser;
+
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.InterruptedIOException;
 import java.io.StringReader;
 import java.net.ConnectException;
@@ -34,19 +37,22 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
 import java.util.stream.Collectors;
-import java.util.stream.Stream;
 import javax.net.ssl.SSLException;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
+import javax.xml.xpath.XPath;
+import javax.xml.xpath.XPathConstants;
+import javax.xml.xpath.XPathExpressionException;
+import javax.xml.xpath.XPathFactory;
+
 import lombok.extern.slf4j.Slf4j;
 import org.apache.hertzbeat.collector.collect.AbstractCollect;
 import org.apache.hertzbeat.collector.collect.common.http.CommonHttpClient;
 import org.apache.hertzbeat.collector.collect.http.promethus.AbstractPrometheusParse;
 import org.apache.hertzbeat.collector.collect.http.promethus.PrometheusParseCreator;
-import org.apache.hertzbeat.collector.collect.http.promethus.exporter.ExporterParser;
-import org.apache.hertzbeat.collector.collect.http.promethus.exporter.MetricFamily;
+import org.apache.hertzbeat.collector.collect.prometheus.parser.MetricFamily;
+import org.apache.hertzbeat.collector.collect.prometheus.parser.OnlineParser;
 import org.apache.hertzbeat.collector.constants.CollectorConstants;
 import org.apache.hertzbeat.collector.dispatch.DispatchConstants;
 import org.apache.hertzbeat.collector.util.CollectUtil;
@@ -63,11 +69,9 @@ import org.apache.hertzbeat.common.util.CommonUtil;
 import org.apache.hertzbeat.common.util.IpDomainUtil;
 import org.apache.http.Header;
 import org.apache.http.HttpHeaders;
-import org.apache.http.HttpHost;
 import org.apache.http.HttpStatus;
 import org.apache.http.auth.AuthScope;
 import org.apache.http.auth.UsernamePasswordCredentials;
-import org.apache.http.client.AuthCache;
 import org.apache.http.client.ClientProtocolException;
 import org.apache.http.client.CredentialsProvider;
 import org.apache.http.client.config.RequestConfig;
@@ -77,8 +81,6 @@ import org.apache.http.client.methods.HttpUriRequest;
 import org.apache.http.client.methods.RequestBuilder;
 import org.apache.http.client.protocol.HttpClientContext;
 import org.apache.http.entity.StringEntity;
-import org.apache.http.impl.auth.DigestScheme;
-import org.apache.http.impl.client.BasicAuthCache;
 import org.apache.http.impl.client.BasicCredentialsProvider;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.util.EntityUtils;
@@ -91,16 +93,25 @@ import org.xml.sax.InputSource;
 import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
+import java.util.Properties;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+import java.util.HashSet;
+import java.util.ArrayList;
+import java.util.Collections;
 
 /**
  * http https collect
  */
 @Slf4j
 public class HttpCollectImpl extends AbstractCollect {
-    private static final Map<Long, ExporterParser> EXPORTER_PARSER_TABLE = new ConcurrentHashMap<>();
-    private final Set<Integer> defaultSuccessStatusCodes = Stream.of(HttpStatus.SC_OK, HttpStatus.SC_CREATED,
-            HttpStatus.SC_ACCEPTED, HttpStatus.SC_MULTIPLE_CHOICES, HttpStatus.SC_MOVED_PERMANENTLY,
-            HttpStatus.SC_MOVED_TEMPORARILY).collect(Collectors.toSet());
+    private final Set<Integer> defaultSuccessStatusCodes = Set.of(
+            HttpStatus.SC_OK,
+            HttpStatus.SC_CREATED,
+            HttpStatus.SC_ACCEPTED,
+            HttpStatus.SC_MULTIPLE_CHOICES,
+            HttpStatus.SC_MOVED_PERMANENTLY,
+            HttpStatus.SC_MOVED_TEMPORARILY);
 
     @Override
     public void preCheck(Metrics metrics) throws IllegalArgumentException {
@@ -133,10 +144,11 @@ public class HttpCollectImpl extends AbstractCollect {
                 builder.setMsg(NetworkConstants.STATUS_CODE + SignConstants.BLANK + statusCode);
                 return;
             }
-            // todo This code converts an InputStream directly to a String. For large data in Prometheus exporters,
-            // this could create large objects, potentially impacting JVM memory space significantly.
-            // Option 1: Parse using InputStream, but this requires significant code changes;
-            // Option 2: Manually trigger garbage collection, similar to how it's done in Dubbo for large inputs.
+            /*
+             this could create large objects, potentially impacting JVM memory space significantly.
+             Option 1: Parse using InputStream, but this requires significant code changes;
+             Option 2: Manually trigger garbage collection, similar to how it's done in Dubbo for large inputs.
+             */
             String resp = EntityUtils.toString(response.getEntity(), StandardCharsets.UTF_8);
             if (!StringUtils.hasText(resp)) {
                 log.info("http response entity is empty, status: {}.", statusCode);
@@ -150,15 +162,17 @@ public class HttpCollectImpl extends AbstractCollect {
                     case DispatchConstants.PARSE_PROM_QL ->
                             parseResponseByPromQl(resp, metrics.getAliasFields(), metrics.getHttp(), builder);
                     case DispatchConstants.PARSE_PROMETHEUS ->
-                            parseResponseByPrometheusExporter(resp, metrics.getAliasFields(), builder);
+                            parseResponseByPrometheusExporter(response.getEntity().getContent(), metrics.getAliasFields(), builder);
                     case DispatchConstants.PARSE_XML_PATH ->
-                            parseResponseByXmlPath(resp, metrics.getAliasFields(), metrics.getHttp(), builder);
+                            parseResponseByXmlPath(resp, metrics, builder, responseTime);
                     case DispatchConstants.PARSE_WEBSITE ->
                             parseResponseByWebsite(resp, metrics, metrics.getHttp(), builder, responseTime);
                     case DispatchConstants.PARSE_SITE_MAP ->
                             parseResponseBySiteMap(resp, metrics.getAliasFields(), builder);
                     case DispatchConstants.PARSE_HEADER ->
                             parseResponseByHeader(builder, metrics.getAliasFields(), response);
+                    case DispatchConstants.PARSE_CONFIG ->
+                            parseResponseByConfig(resp, metrics.getAliasFields(), metrics.getHttp(), builder, responseTime);
                     default ->
                             parseResponseByDefault(resp, metrics.getAliasFields(), metrics.getHttp(), builder, responseTime);
                 }
@@ -329,8 +343,207 @@ public class HttpCollectImpl extends AbstractCollect {
         }
     }
 
-    private void parseResponseByXmlPath(String resp, List<String> aliasFields, HttpProtocol http,
-                                        CollectRep.MetricsData.Builder builder) {
+    private void parseResponseByXmlPath(String resp, Metrics metrics,
+                                        CollectRep.MetricsData.Builder builder, Long responseTime) {
+        HttpProtocol http = metrics.getHttp();
+        List<String> aliasFields = metrics.getAliasFields();
+        String xpathExpression = http.getParseScript();
+        if (!StringUtils.hasText(xpathExpression)) {
+            log.warn("Http collect parse type is xmlPath, but the xpath expression is empty.");
+            builder.setCode(CollectRep.Code.FAIL);
+            builder.setMsg("XPath expression is empty");
+            return;
+        }
+        int keywordNum = CollectUtil.countMatchKeyword(resp, http.getKeyword());
+
+        try {
+            DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
+            dbf.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
+            dbf.setFeature("http://xml.org/sax/features/external-general-entities", false);
+            dbf.setFeature("http://xml.org/sax/features/external-parameter-entities", false);
+            dbf.setXIncludeAware(false);
+            dbf.setExpandEntityReferences(false);
+
+            DocumentBuilder db = dbf.newDocumentBuilder();
+            Document document = db.parse(new InputSource(new StringReader(resp)));
+
+            XPathFactory xpathFactory = XPathFactory.newInstance();
+            XPath xpath = xpathFactory.newXPath();
+
+            NodeList nodeList = (NodeList) xpath.evaluate(xpathExpression, document, XPathConstants.NODESET);
+
+            if (nodeList == null || nodeList.getLength() == 0) {
+                log.debug("XPath expression '{}' returned no nodes.", xpathExpression);
+                boolean requestedSummaryFields = aliasFields.stream()
+                        .anyMatch(alias -> NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias)
+                                || CollectorConstants.KEYWORD.equalsIgnoreCase(alias));
+
+                if (requestedSummaryFields) {
+                    CollectRep.ValueRow.Builder valueRowBuilder = CollectRep.ValueRow.newBuilder();
+                    for (String alias : aliasFields) {
+                        if (NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias)) {
+                            valueRowBuilder.addColumn(responseTime.toString());
+                        } else if (CollectorConstants.KEYWORD.equalsIgnoreCase(alias)) {
+                            valueRowBuilder.addColumn(Integer.toString(keywordNum));
+                        } else {
+                            valueRowBuilder.addColumn(CommonConstants.NULL_VALUE);
+                        }
+                    }
+                    builder.addValueRow(valueRowBuilder.build());
+                }
+                return;
+            }
+
+            for (int i = 0; i < nodeList.getLength(); i++) {
+                Node node = nodeList.item(i);
+                CollectRep.ValueRow.Builder valueRowBuilder = CollectRep.ValueRow.newBuilder();
+
+                for (String alias : aliasFields) {
+                    if (NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias)) {
+                        valueRowBuilder.addColumn(responseTime.toString());
+                    } else if (CollectorConstants.KEYWORD.equalsIgnoreCase(alias)) {
+                        valueRowBuilder.addColumn(Integer.toString(keywordNum));
+                    } else {
+                        try {
+                            String value = (String) xpath.evaluate(alias, node, XPathConstants.STRING);
+                            valueRowBuilder.addColumn(StringUtils.hasText(value) ? value : CommonConstants.NULL_VALUE);
+                        } catch (XPathExpressionException e) {
+                            log.warn("Failed to evaluate XPath '{}' for node [{}]: {}", alias, node.getNodeName(), e.getMessage());
+                            valueRowBuilder.addColumn(CommonConstants.NULL_VALUE);
+                        }
+                    }
+                }
+                builder.addValueRow(valueRowBuilder.build());
+            }
+
+        } catch (Exception e) {
+            log.warn("Failed to parse XML response with XPath '{}': {}", xpathExpression, e.getMessage(), e);
+            builder.setCode(CollectRep.Code.FAIL);
+            builder.setMsg("Failed to parse XML response: " + e.getMessage());
+        }
+    }
+
+
+
+    /**
+     * Parses the response body in Properties/Config format.
+     * Two modes are supported:
+     * 1. single-object mode: if http.parseScript is null, aliasFields are treated as indicator names.
+     * - If there is a locator in the indicator definition, use the locator as the key of the Properties.
+     * - Otherwise, use aliasField (metric name) as the key for Properties.
+     * Generate a single row of data.
+     * 2. array mode: if http.parseScript is not empty (e.g. “users”), treat it as an array base path.
+     * Treat aliasFields as the attribute name of an array element, and generate a single row of data for each array index. locator is invalid in this mode.
+     *
+     * @param resp Response body string
+     * @param aliasFields List of metrics aliases (i.e., the list of fields in metrics.fields).
+     * @param http http protocol configuration
+     * @param builder The metrics data builder.
+     * @param responseTime response time
+     */
+    private void parseResponseByConfig(String resp, List<String> aliasFields, HttpProtocol http,
+                                       CollectRep.MetricsData.Builder builder, Long responseTime) {
+        if (!StringUtils.hasText(resp)) {
+            log.warn("Http collect parse type is config, but response body is empty.");
+            builder.setCode(CollectRep.Code.FAIL);
+            builder.setMsg("Response body is empty");
+            return;
+        }
+
+        Properties properties = new Properties();
+        try (StringReader reader = new StringReader(resp)) {
+            properties.load(reader);
+        } catch (IOException e) {
+            log.warn("Failed to parse config response: {}", e.getMessage(), e);
+            builder.setCode(CollectRep.Code.FAIL);
+            builder.setMsg("Failed to parse config response: " + e.getMessage());
+            return;
+        }
+        String arrayBasePath = http.getParseScript();
+        int keywordNum = CollectUtil.countMatchKeyword(resp, http.getKeyword());
+
+        if (!StringUtils.hasText(arrayBasePath)) {
+            CollectRep.ValueRow.Builder valueRowBuilder = CollectRep.ValueRow.newBuilder();
+            for (String alias : aliasFields) {
+                if (NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias)) {
+                    valueRowBuilder.addColumn(responseTime.toString());
+                } else if (CollectorConstants.KEYWORD.equalsIgnoreCase(alias)) {
+                    valueRowBuilder.addColumn(Integer.toString(keywordNum));
+                } else {
+                    String value = properties.getProperty(alias);
+                    valueRowBuilder.addColumn(value != null ? value : CommonConstants.NULL_VALUE);
+                }
+            }
+            CollectRep.ValueRow valueRow = valueRowBuilder.build();
+            if (hasMeaningfulDataInRow(valueRow, aliasFields)) {
+                builder.addValueRow(valueRow);
+            } else {
+                log.warn("No meaningful data found in single config object response for aliasFields: {}", aliasFields);
+            }
+        } else {
+            Pattern pattern = Pattern.compile("^" + Pattern.quote(arrayBasePath) + "\\[(\\d+)]\\.");
+            Set<Integer> existingIndices = new HashSet<>();
+            for (String key : properties.stringPropertyNames()) {
+                Matcher matcher = pattern.matcher(key);
+                if (matcher.find()) {
+                    try {
+                        int index = Integer.parseInt(matcher.group(1));
+                        existingIndices.add(index);
+                    } catch (NumberFormatException e) {
+                        log.error("Could not parse index from key: {}", key);
+                    }
+                }
+            }
+            if (existingIndices.isEmpty()) {
+                log.warn("Could not find any array elements for base path '{}' in config response.", arrayBasePath);
+                return;
+            }
+            List<Integer> sortedIndices = new ArrayList<>(existingIndices);
+            Collections.sort(sortedIndices);
+            for (int i : sortedIndices) {
+                CollectRep.ValueRow.Builder valueRowBuilder = CollectRep.ValueRow.newBuilder();
+                for (String alias : aliasFields) {
+                    if (NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias)) {
+                        valueRowBuilder.addColumn(responseTime.toString());
+                    } else if (CollectorConstants.KEYWORD.equalsIgnoreCase(alias)) {
+                        valueRowBuilder.addColumn(Integer.toString(keywordNum));
+                    } else {
+                        String currentKey = arrayBasePath + "[" + i + "]." + alias;
+                        String value = properties.getProperty(currentKey);
+                        valueRowBuilder.addColumn(value != null ? value : CommonConstants.NULL_VALUE);
+                    }
+                }
+                CollectRep.ValueRow valueRow = valueRowBuilder.build();
+                if (hasMeaningfulDataInRow(valueRow, aliasFields)) {
+                    builder.addValueRow(valueRowBuilder.build());
+                }
+            }
+        }
+    }
+
+    private boolean hasMeaningfulDataInRow(CollectRep.ValueRow valueRow, List<String> aliasFields) {
+        if (valueRow.getColumnsCount() == 0) {
+            return false;
+        }
+        if (valueRow.getColumnsCount() != aliasFields.size()) {
+            log.error("Column count ({}) mismatch with aliasFields size ({}) when checking meaningful data.",
+                    valueRow.getColumnsCount(), aliasFields.size());
+            return false;
+        }
+
+        boolean hasMeaningfulData = false;
+        for (int i = 0; i < valueRow.getColumnsCount(); i++) {
+            String columnValue = valueRow.getColumns(i);
+            String alias = aliasFields.get(i);
+            if (!CommonConstants.NULL_VALUE.equals(columnValue) && (!NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias) && !CollectorConstants.KEYWORD.equalsIgnoreCase(alias))) {
+                hasMeaningfulData = true;
+                break;
+            }
+            if ((NetworkConstants.RESPONSE_TIME.equalsIgnoreCase(alias) || CollectorConstants.KEYWORD.equalsIgnoreCase(alias)) && !CommonConstants.NULL_VALUE.equals(columnValue)) {
+                hasMeaningfulData = true;
+            }
+        }
+        return hasMeaningfulData;
     }
 
     private void parseResponseByJsonPath(String resp, List<String> aliasFields, HttpProtocol http,
@@ -387,36 +600,22 @@ public class HttpCollectImpl extends AbstractCollect {
         prometheusParser.handle(resp, aliasFields, http, builder);
     }
 
-    private void parseResponseByPrometheusExporter(String resp, List<String> aliasFields,
-                                                   CollectRep.MetricsData.Builder builder) {
-        if (!EXPORTER_PARSER_TABLE.containsKey(builder.getId())) {
-            EXPORTER_PARSER_TABLE.put(builder.getId(), new ExporterParser());
+    private void parseResponseByPrometheusExporter(InputStream content, List<String> aliasFields, CollectRep.MetricsData.Builder builder) throws IOException {
+        Map<String, MetricFamily> metricFamilyMap = OnlineParser.parseMetrics(content);
+        if (metricFamilyMap == null || metricFamilyMap.isEmpty()) {
+            return;
         }
-        ExporterParser parser = EXPORTER_PARSER_TABLE.get(builder.getId());
-        Map<String, MetricFamily> metricFamilyMap = parser.textToMetric(resp);
         String metrics = builder.getMetrics();
         if (metricFamilyMap.containsKey(metrics)) {
             MetricFamily metricFamily = metricFamilyMap.get(metrics);
             for (MetricFamily.Metric metric : metricFamily.getMetricList()) {
-                Map<String, String> labelMap = metric.getLabelPair()
+                Map<String, String> labelMap = metric.getLabels()
                         .stream()
                         .collect(Collectors.toMap(MetricFamily.Label::getName, MetricFamily.Label::getValue));
                 CollectRep.ValueRow.Builder valueRowBuilder = CollectRep.ValueRow.newBuilder();
                 for (String aliasField : aliasFields) {
                     if ("value".equals(aliasField)) {
-                        if (metric.getCounter() != null) {
-                            valueRowBuilder.addColumn(String.valueOf(metric.getCounter().getValue()));
-                        } else if (metric.getGauge() != null) {
-                            valueRowBuilder.addColumn(String.valueOf(metric.getGauge().getValue()));
-                        } else if (metric.getUntyped() != null) {
-                            valueRowBuilder.addColumn(String.valueOf(metric.getUntyped().getValue()));
-                        } else if (metric.getInfo() != null) {
-                            valueRowBuilder.addColumn(String.valueOf(metric.getInfo().getValue()));
-                        } else if (metric.getSummary() != null) {
-                            valueRowBuilder.addColumn(String.valueOf(metric.getSummary().getValue()));
-                        } else if (metric.getHistogram() != null) {
-                            valueRowBuilder.addColumn(String.valueOf(metric.getHistogram().getValue()));
-                        }
+                        valueRowBuilder.addColumn(String.valueOf(metric.getValue()));
                     } else {
                         String columnValue = labelMap.get(aliasField);
                         valueRowBuilder.addColumn(columnValue == null ? CommonConstants.NULL_VALUE : columnValue);
@@ -473,11 +672,10 @@ public class HttpCollectImpl extends AbstractCollect {
                 CredentialsProvider provider = new BasicCredentialsProvider();
                 UsernamePasswordCredentials credentials = new UsernamePasswordCredentials(auth.getDigestAuthUsername(),
                         auth.getDigestAuthPassword());
-                provider.setCredentials(AuthScope.ANY, credentials);
-                AuthCache authCache = new BasicAuthCache();
-                authCache.put(new HttpHost(httpProtocol.getHost(), Integer.parseInt(httpProtocol.getPort())), new DigestScheme());
+                AuthScope authScope = new AuthScope(httpProtocol.getHost(), Integer.parseInt(httpProtocol.getPort()));
+                provider.setCredentials(authScope, credentials);
+
                 clientContext.setCredentialsProvider(provider);
-                clientContext.setAuthCache(authCache);
                 return clientContext;
             }
         }
@@ -512,7 +710,7 @@ public class HttpCollectImpl extends AbstractCollect {
         Map<String, String> params = httpProtocol.getParams();
         boolean enableUrlEncoding = Boolean.parseBoolean(httpProtocol.getEnableUrlEncoding());
         StringBuilder queryParams = new StringBuilder();
-        
+
         if (params != null && !params.isEmpty()) {
             for (Map.Entry<String, String> param : params.entrySet()) {
                 String key = param.getKey();
@@ -522,7 +720,7 @@ public class HttpCollectImpl extends AbstractCollect {
                     continue;
                 }
 
-                if (queryParams.length() > 0) {
+                if (!queryParams.isEmpty()) {
                     queryParams.append("&");
                 }
 
@@ -540,7 +738,7 @@ public class HttpCollectImpl extends AbstractCollect {
                 }
             }
         }
-        
+
         // The default request header can be overridden if customized
         // keep-alive
         requestBuilder.addHeader(HttpHeaders.CONNECTION, NetworkConstants.KEEP_ALIVE);
@@ -581,7 +779,7 @@ public class HttpCollectImpl extends AbstractCollect {
 
         // if it has payload, would override post params
         if (StringUtils.hasLength(httpProtocol.getPayload()) && (HttpMethod.POST.matches(httpMethod) || HttpMethod.PUT.matches(httpMethod))) {
-            requestBuilder.setEntity(new StringEntity(httpProtocol.getPayload(), StandardCharsets.UTF_8));
+            requestBuilder.setEntity(new StringEntity(TimeExpressionUtil.calculate(httpProtocol.getPayload()), StandardCharsets.UTF_8));
         }
 
         // uri encode
@@ -600,10 +798,10 @@ public class HttpCollectImpl extends AbstractCollect {
         }
 
         // append query params
-        if (queryParams.length() > 0) {
-            uri += (uri.contains("?") ? "&" : "?") + queryParams.toString();
+        if (!queryParams.isEmpty()) {
+            uri += (uri.contains("?") ? "&" : "?") + queryParams;
         }
-        
+
         String finalUri;
         if (IpDomainUtil.isHasSchema(httpProtocol.getHost())) {
             finalUri = httpProtocol.getHost() + ":" + httpProtocol.getPort() + uri;
@@ -619,7 +817,7 @@ public class HttpCollectImpl extends AbstractCollect {
                 finalUri = NetworkConstants.HTTP_HEADER + baseUri;
             }
         }
-        
+
         try {
             requestBuilder.setUri(finalUri);
         } catch (IllegalArgumentException e) {
