@@ -23,7 +23,6 @@ import jakarta.persistence.criteria.CriteriaBuilder;
 import jakarta.persistence.criteria.Predicate;
 import jakarta.servlet.http.HttpServletResponse;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.commons.lang3.StringUtils;
 import org.apache.hertzbeat.alert.dao.AlertDefineBindDao;
 import org.apache.hertzbeat.collector.dispatch.DispatchConstants;
 import org.apache.hertzbeat.common.constants.CommonConstants;
@@ -34,28 +33,26 @@ import org.apache.hertzbeat.common.entity.grafana.GrafanaDashboard;
 import org.apache.hertzbeat.common.entity.job.Configmap;
 import org.apache.hertzbeat.common.entity.job.Job;
 import org.apache.hertzbeat.common.entity.job.Metrics;
-import org.apache.hertzbeat.common.entity.job.protocol.CommonRequestProtocol;
 import org.apache.hertzbeat.common.entity.manager.Collector;
 import org.apache.hertzbeat.common.entity.manager.CollectorMonitorBind;
+import org.apache.hertzbeat.common.entity.manager.Label;
 import org.apache.hertzbeat.common.entity.manager.Monitor;
-import org.apache.hertzbeat.common.entity.manager.MonitorBind;
 import org.apache.hertzbeat.common.entity.manager.Param;
 import org.apache.hertzbeat.common.entity.manager.ParamDefine;
-import org.apache.hertzbeat.common.entity.manager.SdMonitorParam;
 import org.apache.hertzbeat.common.entity.message.CollectRep;
-import org.apache.hertzbeat.common.entity.sd.ServiceDiscoveryProtocol;
 import org.apache.hertzbeat.common.support.event.MonitorDeletedEvent;
 import org.apache.hertzbeat.common.util.AesUtil;
+import org.apache.hertzbeat.common.util.CommonUtil;
 import org.apache.hertzbeat.common.util.FileUtil;
 import org.apache.hertzbeat.common.util.IntervalExpressionUtil;
 import org.apache.hertzbeat.common.util.IpDomainUtil;
 import org.apache.hertzbeat.common.util.JsonUtil;
-import org.apache.hertzbeat.common.util.SdMonitorOperator;
 import org.apache.hertzbeat.common.util.SnowFlakeIdGenerator;
 import org.apache.hertzbeat.grafana.service.DashboardService;
 import org.apache.hertzbeat.manager.config.ManagerSseManager;
 import org.apache.hertzbeat.manager.dao.CollectorDao;
 import org.apache.hertzbeat.manager.dao.CollectorMonitorBindDao;
+import org.apache.hertzbeat.manager.dao.LabelDao;
 import org.apache.hertzbeat.manager.dao.MonitorBindDao;
 import org.apache.hertzbeat.manager.dao.MonitorDao;
 import org.apache.hertzbeat.manager.dao.ParamDao;
@@ -64,8 +61,8 @@ import org.apache.hertzbeat.manager.pojo.dto.MonitorDto;
 import org.apache.hertzbeat.manager.scheduler.CollectJobScheduling;
 import org.apache.hertzbeat.manager.service.AppService;
 import org.apache.hertzbeat.manager.service.ImExportService;
+import org.apache.hertzbeat.manager.service.LabelService;
 import org.apache.hertzbeat.manager.service.MonitorService;
-import org.apache.hertzbeat.manager.service.TagService;
 import org.apache.hertzbeat.manager.support.exception.MonitorDatabaseException;
 import org.apache.hertzbeat.manager.support.exception.MonitorDetectException;
 import org.apache.hertzbeat.warehouse.service.WarehouseService;
@@ -81,15 +78,14 @@ import org.springframework.http.MediaType;
 import org.springframework.stereotype.Service;
 import org.springframework.transaction.annotation.Transactional;
 import org.springframework.util.CollectionUtils;
+import org.springframework.util.StringUtils;
 import org.springframework.web.multipart.MultipartFile;
 
 import java.net.URLEncoder;
 import java.nio.charset.StandardCharsets;
 import java.time.LocalDateTime;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
@@ -109,15 +105,11 @@ public class MonitorServiceImpl implements MonitorService {
     private static final Long MONITOR_ID_TMP = 1000000000L;
     private static final byte ALL_MONITOR_STATUS = 9;
 
-    private static final int TAG_LENGTH = 2;
-
     private static final String CONTENT_VALUE = MediaType.APPLICATION_OCTET_STREAM_VALUE + SignConstants.SINGLE_MARK + "charset=" + StandardCharsets.UTF_8;
     private final Map<String, ImExportService> imExportServiceMap = new HashMap<>();
     @Autowired
     private AppService appService;
     @Autowired
-    private TagService tagService;
-    @Autowired
     private CollectJobScheduling collectJobScheduling;
     @Autowired
     private MonitorDao monitorDao;
@@ -139,6 +131,10 @@ public class MonitorServiceImpl implements MonitorService {
     private DashboardService dashboardService;
     @Autowired
     private ManagerSseManager managerSseManager;
+    @Autowired
+    private LabelDao labelDao;
+    @Autowired
+    private LabelService labelService;
 
     public MonitorServiceImpl(List<ImExportService> imExportServiceList) {
         imExportServiceList.forEach(it -> imExportServiceMap.put(it.type(), it));
@@ -147,25 +143,80 @@ public class MonitorServiceImpl implements MonitorService {
     @Override
     @Transactional(readOnly = true)
     public void detectMonitor(Monitor monitor, List<Param> params, String collector) throws MonitorDetectException {
-        final Optional<Param> sdParam = SdMonitorOperator.getSdParam(params);
-
-        if (sdParam.isPresent()) {
-            collectOneTimeSdData(monitor, collector, sdParam.get());
-        } else {
+        if (CommonConstants.SCRAPE_STATIC.equals(monitor.getScrape()) || !StringUtils.hasText(monitor.getScrape())) {
             detectMonitorDirectly(monitor, params, collector);
+        } else {
+            detectSdMonitor(monitor, params, collector);
         }
     }
 
     @Override
     @Transactional(rollbackFor = Exception.class)
     public void addMonitor(Monitor monitor, List<Param> params, String collector, GrafanaDashboard grafanaDashboard) throws RuntimeException {
-        final Optional<Param> sdParam = SdMonitorOperator.getSdParam(params);
-        if (sdParam.isPresent()) {
-            addAndSaveMonitorJob(monitor.clone(), params, collector, SdMonitorParam.builder().sdParam(sdParam.get()).build(), grafanaDashboard);
-            return;
+        // Apply for monitor id
+        long monitorId = SnowFlakeIdGenerator.generateId();
+        Map<String, String> labels = monitor.getLabels();
+        if (labels == null) {
+            labels = new HashMap<>(8);
+            monitor.setLabels(labels);
+        }
+        List<Label> addLabels = labelService.determineNewLabels(labels.entrySet());
+
+        if (!addLabels.isEmpty()) {
+            labelDao.saveAll(addLabels);
         }
 
-        addAndSaveMonitorJob(monitor, params, collector, null, grafanaDashboard);
+        // Construct the collection task Job entity
+        boolean isStatic = CommonConstants.SCRAPE_STATIC.equals(monitor.getScrape()) || !StringUtils.hasText(monitor.getScrape());
+        String app = isStatic ? monitor.getApp() : monitor.getScrape();
+        Job appDefine = appService.getAppDefine(app);
+        if (!isStatic) {
+            appDefine.setSd(true);
+        }
+        if (CommonConstants.PROMETHEUS.equals(monitor.getApp())) {
+            appDefine.setApp(CommonConstants.PROMETHEUS_APP_PREFIX + monitor.getName());
+        }
+        appDefine.setMonitorId(monitorId);
+        appDefine.setDefaultInterval(monitor.getIntervals());
+        appDefine.setCyclic(true);
+        appDefine.setTimestamp(System.currentTimeMillis());
+        Map<String, String> metadata = Map.of(CommonConstants.LABEL_INSTANCE_NAME, monitor.getName(),
+                CommonConstants.LABEL_INSTANCE_HOST, monitor.getHost());
+        appDefine.setMetadata(metadata);
+        appDefine.setLabels(monitor.getLabels());
+        appDefine.setAnnotations(monitor.getAnnotations());
+        List<Configmap> configmaps = params.stream().map(param -> {
+            param.setMonitorId(monitorId);
+            return new Configmap(param.getField(), param.getParamValue(), param.getType());
+        }).collect(Collectors.toList());
+        appDefine.setConfigmap(configmaps);
+        long jobId = collector == null ? collectJobScheduling.addAsyncCollectJob(appDefine, null) :
+                collectJobScheduling.addAsyncCollectJob(appDefine, collector);
+        try {
+            detectMonitor(monitor, params, collector);
+        } catch (Exception ignored) {}
+
+        try {
+            if (collector != null) {
+                CollectorMonitorBind collectorMonitorBind = CollectorMonitorBind.builder()
+                        .collector(collector)
+                        .monitorId(monitorId)
+                        .build();
+                collectorMonitorBindDao.save(collectorMonitorBind);
+            }
+            monitor.setId(monitorId);
+            monitor.setJobId(jobId);
+            // create grafana dashboard
+            if (monitor.getApp().equals(CommonConstants.PROMETHEUS) && grafanaDashboard != null && grafanaDashboard.isEnabled()) {
+                dashboardService.createOrUpdateDashboard(grafanaDashboard.getTemplate(), monitorId);
+            }
+            monitorDao.save(monitor);
+            paramDao.saveAll(params);
+        } catch (Exception e) {
+            log.error("Error while adding monitor: {}", e.getMessage(), e);
+            collectJobScheduling.cancelAsyncCollectJob(jobId);
+            throw new MonitorDatabaseException(e.getMessage());
+        }
     }
 
     @Override
@@ -233,7 +284,7 @@ public class MonitorServiceImpl implements MonitorService {
             }
         }
         // the dispatch collector must exist if pin
-        if (StringUtils.isNotBlank(monitorDto.getCollector())) {
+        if (StringUtils.hasText(monitorDto.getCollector())) {
             Optional<Collector> optionalCollector = collectorDao.findCollectorByName(monitorDto.getCollector());
             if (optionalCollector.isEmpty()) {
                 throw new IllegalArgumentException("The pinned collector does not exist.");
@@ -250,7 +301,7 @@ public class MonitorServiceImpl implements MonitorService {
                 if (paramDefine.isRequired() && (param == null || param.getParamValue() == null)) {
                     throw new IllegalArgumentException("Params field " + field + " is required.");
                 }
-                if (param != null && param.getParamValue() != null && StringUtils.isNotBlank(param.getParamValue())) {
+                if (param != null && StringUtils.hasText(param.getParamValue())) {
                     switch (paramDefine.getType()) {
                         case "number":
                             double doubleValue;
@@ -376,7 +427,6 @@ public class MonitorServiceImpl implements MonitorService {
     @Override
     @Transactional(rollbackFor = Exception.class)
     public void modifyMonitor(Monitor monitor, List<Param> params, String collector, GrafanaDashboard grafanaDashboard) throws RuntimeException {
-        final Optional<Param> sdParam = SdMonitorOperator.getSdParam(params);
         long monitorId = monitor.getId();
         // Check to determine whether the monitor corresponding to the monitor id exists
         Optional<Monitor> queryOption = monitorDao.findById(monitorId);
@@ -394,35 +444,20 @@ public class MonitorServiceImpl implements MonitorService {
             monitor.setLabels(labels);
         }
 
+        List<Label> addLabels = labelService.determineNewLabels(labels.entrySet());
+
+        if (!addLabels.isEmpty()) {
+            labelDao.saveAll(addLabels);
+        }
+
+        boolean isStatic = CommonConstants.SCRAPE_STATIC.equals(monitor.getScrape()) || !StringUtils.hasText(monitor.getScrape());
         if (preMonitor.getStatus() != CommonConstants.MONITOR_PAUSED_CODE) {
             // Construct the collection task Job entity
-            Job appDefine = appService.getAppDefine(monitor.getApp());
-            if (sdParam.isPresent()) {
-                // not allow to modify a sub monitor to main monitor
-                labels.entrySet()
-                        .stream()
-                        .filter(label -> org.apache.commons.lang3.StringUtils.equals(label.getKey(), CommonConstants.TAG_AUTO_CREATED))
-                        .findFirst()
-                        .ifPresent(label -> {
-                            final MonitorBind isSubMonitorBefore = monitorBindDao.findMonitorBindByBizIdAndMonitorIdAndType(Long.valueOf(label.getValue()),
-                                    monitorId, CommonConstants.MONITOR_BIND_TYPE_SD_SUB_MONITOR);
-                            if (Objects.nonNull(isSubMonitorBefore)) {
-                                throw new UnsupportedOperationException("Can not change a auto-created monitor to sd! ");
-                            }
-                        });
-                // create main monitor bind
-                final List<MonitorBind> mainMonitorBind = monitorBindDao.findMonitorBindByBizIdAndType(monitorId, CommonConstants.MONITOR_BIND_TYPE_SD_MAIN_MONITOR);
-                if (CollectionUtils.isEmpty(mainMonitorBind)) {
-                    monitorBindDao.save(Objects.requireNonNull(
-                            SdMonitorOperator.buildSdMainMonitorBind(
-                                    SdMonitorParam.builder().sdParam(sdParam.get()).build(), monitorId
-                            )));
-                }
-
-                appDefine = SdMonitorOperator.constructSdJob(appDefine, sdParam.get());
-                labels.put(CommonConstants.TAG_SD_MAIN_MONITOR, ServiceDiscoveryProtocol.Type.getType(sdParam.get().getField()).name());
+            String app = isStatic ? monitor.getApp() : monitor.getScrape();
+            Job appDefine = appService.getAppDefine(app);
+            if (!isStatic) {
+                appDefine.setSd(true);
             }
-
             if (CommonConstants.PROMETHEUS.equals(monitor.getApp())) {
                 appDefine.setApp(CommonConstants.PROMETHEUS_APP_PREFIX + monitor.getName());
             }
@@ -450,8 +485,7 @@ public class MonitorServiceImpl implements MonitorService {
             // execute only in non paused status
             try {
                 detectMonitor(monitor, params, collector);
-            } catch (Exception ignored) {
-            }
+            } catch (Exception ignored) {}
         }
 
         // After the update is successfully released, refresh the database
@@ -474,12 +508,6 @@ public class MonitorServiceImpl implements MonitorService {
                 }
             }
             monitorDao.save(monitor);
-
-            // delete all sub monitor if sd param is removed
-            final List<MonitorBind> subMonitorBindList = monitorBindDao.findMonitorBindByBizIdAndType(monitorId, CommonConstants.MONITOR_BIND_TYPE_SD_SUB_MONITOR);
-            if (!CollectionUtils.isEmpty(subMonitorBindList) && sdParam.isEmpty()) {
-                deleteMonitors(subMonitorBindList.stream().map(MonitorBind::getMonitorId).collect(Collectors.toSet()));
-            }
             paramDao.saveAll(params);
         } catch (Exception e) {
             log.error(e.getMessage(), e);
@@ -501,12 +529,6 @@ public class MonitorServiceImpl implements MonitorService {
         if (CollectionUtils.isEmpty(ids)) {
             return;
         }
-
-        final List<MonitorBind> allSubMonitorBind = monitorBindDao.findAllByBizIdInAndType(ids, CommonConstants.MONITOR_BIND_TYPE_SD_SUB_MONITOR);
-        if (!CollectionUtils.isEmpty(allSubMonitorBind)) {
-            ids.addAll(allSubMonitorBind.stream().map(MonitorBind::getMonitorId).collect(Collectors.toSet()));
-        }
-
         List<Monitor> monitors = monitorDao.findMonitorsByIdIn(ids);
         if (!monitors.isEmpty()) {
             monitorDao.deleteAll(monitors);
@@ -531,13 +553,15 @@ public class MonitorServiceImpl implements MonitorService {
             MonitorDto monitorDto = new MonitorDto();
             List<Param> params = paramDao.findParamsByMonitorId(id);
             monitorDto.setParams(params);
-            if (DispatchConstants.PROTOCOL_PROMETHEUS.equalsIgnoreCase(monitor.getApp())) {
+            if (DispatchConstants.PROTOCOL_PROMETHEUS.equalsIgnoreCase(monitor.getApp()) || monitor.getType() == CommonConstants.MONITOR_TYPE_PUSH_AUTO_CREATE) {
                 List<CollectRep.MetricsData> metricsDataList = warehouseService.queryMonitorMetricsData(id);
                 List<String> metrics = metricsDataList.stream().map(CollectRep.MetricsData::getMetrics).collect(Collectors.toList());
                 monitorDto.setMetrics(metrics);
                 monitorDto.setGrafanaDashboard(dashboardService.getDashboardByMonitorId(id));
             } else {
-                Job job = appService.getAppDefine(monitor.getApp());
+                boolean isStatic = CommonConstants.SCRAPE_STATIC.equals(monitor.getScrape()) || !StringUtils.hasText(monitor.getScrape());
+                String type = isStatic ? monitor.getApp() : monitor.getScrape();
+                Job job = appService.getAppDefine(type);
                 List<String> metrics = job.getMetrics().stream()
                         .filter(Metrics::isVisible)
                         .map(Metrics::getName).collect(Collectors.toList());
@@ -563,7 +587,7 @@ public class MonitorServiceImpl implements MonitorService {
                 }
                 andList.add(inPredicate);
             }
-            if (StringUtils.isNotBlank(app)) {
+            if (StringUtils.hasText(app)) {
                 Predicate predicateApp = criteriaBuilder.equal(root.get("app"), app);
                 andList.add(predicateApp);
             }
@@ -575,17 +599,17 @@ public class MonitorServiceImpl implements MonitorService {
             Predicate andPredicate = criteriaBuilder.and(andList.toArray(andPredicates));
 
             List<Predicate> orList = new ArrayList<>();
-            if (StringUtils.isNotBlank(search)) {
+            if (StringUtils.hasText(search)) {
                 Predicate predicateHost = criteriaBuilder.like(root.get("host"), "%" + search + "%");
                 Predicate predicateName = criteriaBuilder.like(criteriaBuilder.lower(root.get("name")), "%" + search.toLowerCase() + "%");
-                if (StringUtils.isNumeric(search)){
+                if (CommonUtil.isNumeric(search)){
                     Predicate predicateId = criteriaBuilder.equal(root.get("id"), Long.parseLong(search));
                     orList.add(predicateId);
                 }
                 orList.add(predicateHost);
                 orList.add(predicateName);
             }
-            if (StringUtils.isNotBlank(labels)) {
+            if (StringUtils.hasText(labels)) {
                 String[] labelAres = labels.split(",");
                 for (String label : labelAres) {
                     String[] labelArr = label.split(":");
@@ -620,18 +644,10 @@ public class MonitorServiceImpl implements MonitorService {
     }
 
     @Override
-    public void cancelManageMonitors(HashSet<Long> ids) {
+    public void cancelManageMonitors(Set<Long> ids) {
         if (CollectionUtils.isEmpty(ids)) {
             return;
         }
-
-        final Set<Long> subMonitorIds = monitorBindDao.findAllByBizIdInAndType(ids, CommonConstants.MONITOR_BIND_TYPE_SD_SUB_MONITOR).stream()
-                .map(MonitorBind::getMonitorId)
-                .collect(Collectors.toSet());
-        if (!CollectionUtils.isEmpty(subMonitorIds)) {
-            ids.addAll(subMonitorIds);
-        }
-
         // Update monitoring status Delete corresponding monitoring periodic task
         // The jobId is not deleted, and the jobId is reused again after the management is started.
         List<Monitor> managedMonitors = monitorDao.findMonitorsByIdIn(ids)
@@ -648,7 +664,7 @@ public class MonitorServiceImpl implements MonitorService {
     }
 
     @Override
-    public void enableManageMonitors(HashSet<Long> ids) {
+    public void enableManageMonitors(Set<Long> ids) {
         // Update monitoring status Add corresponding monitoring periodic task
         List<Monitor> unManagedMonitors = monitorDao.findMonitorsByIdIn(ids)
                 .stream().filter(monitor ->
@@ -662,20 +678,12 @@ public class MonitorServiceImpl implements MonitorService {
         for (Monitor monitor : unManagedMonitors) {
             // Construct the collection task Job entity
             List<Param> params = paramDao.findParamsByMonitorId(monitor.getId());
-            final Optional<Param> sdParam = SdMonitorOperator.getSdParam(params);
-            Job appDefine = appService.getAppDefine(monitor.getApp());
-            if (sdParam.isPresent()) {
-                final List<MonitorBind> mainMonitorBind = monitorBindDao.findMonitorBindByBizIdAndType(monitor.getId(), CommonConstants.MONITOR_BIND_TYPE_SD_MAIN_MONITOR);
-                if (CollectionUtils.isEmpty(mainMonitorBind)) {
-                    monitorBindDao.save(Objects.requireNonNull(
-                            SdMonitorOperator.buildSdMainMonitorBind(
-                                    SdMonitorParam.builder().sdParam(sdParam.get()).build(), monitor.getId()
-                            )));
-                }
-
-                appDefine = SdMonitorOperator.constructSdJob(appDefine, sdParam.get());
+            boolean isStatic = CommonConstants.SCRAPE_STATIC.equals(monitor.getScrape()) || !StringUtils.hasText(monitor.getScrape());
+            String app = isStatic ? monitor.getApp() : monitor.getScrape();
+            Job appDefine = appService.getAppDefine(app);
+            if (!isStatic) {
+                appDefine.setSd(true);
             }
-
             if (CommonConstants.PROMETHEUS.equals(monitor.getApp())) {
                 appDefine.setApp(CommonConstants.PROMETHEUS_APP_PREFIX + monitor.getName());
             }
@@ -691,7 +699,7 @@ public class MonitorServiceImpl implements MonitorService {
             List<Configmap> configmaps = params.stream().map(param ->
                     new Configmap(param.getField(), param.getParamValue(), param.getType())).collect(Collectors.toList());
             List<ParamDefine> paramDefaultValue = appDefine.getParams().stream()
-                    .filter(item -> StringUtils.isNotBlank(item.getDefaultValue()))
+                    .filter(item -> StringUtils.hasText(item.getDefaultValue()))
                     .toList();
             paramDefaultValue.forEach(defaultVar -> {
                 if (configmaps.stream().noneMatch(item -> item.getKey().equals(defaultVar.getField()))) {
@@ -752,25 +760,6 @@ public class MonitorServiceImpl implements MonitorService {
         }).filter(Objects::nonNull).collect(Collectors.toList());
     }
 
-    @Override
-    @Transactional(rollbackFor = Exception.class)
-    public void copyMonitors(List<Long> ids) {
-
-        ids.stream().parallel().forEach(id -> {
-            // get monitor and Params according id
-            Optional<Monitor> monitorOpt = monitorDao.findById(id);
-            List<Param> params = paramDao.findParamsByMonitorId(id);
-
-            monitorOpt.ifPresentOrElse(monitor -> {
-                // deep copy original monitor to achieve persist in JPA
-                Monitor newMonitor = JsonUtil.fromJson(JsonUtil.toJson(monitor), Monitor.class);
-                if (newMonitor != null) {
-                    copyMonitor(newMonitor, params);
-                }
-            }, () -> log.warn("can not find the monitor for id ：{}", id));
-        });
-    }
-
     @Override
     public void updateAppCollectJob(Job job) {
         List<Monitor> monitors = monitorDao.findMonitorsByAppEquals(job.getApp())
@@ -807,7 +796,7 @@ public class MonitorServiceImpl implements MonitorService {
                 List<Configmap> configmaps = params.stream().map(param -> new Configmap(param.getField(),
                         param.getParamValue(), param.getType())).collect(Collectors.toList());
                 List<ParamDefine> paramDefaultValue = appDefine.getParams().stream()
-                        .filter(item -> StringUtils.isNotBlank(item.getDefaultValue()))
+                        .filter(item -> StringUtils.hasText(item.getDefaultValue()))
                         .toList();
                 paramDefaultValue.forEach(defaultVar -> {
                     if (configmaps.stream().noneMatch(item -> item.getKey().equals(defaultVar.getField()))) {
@@ -827,80 +816,7 @@ public class MonitorServiceImpl implements MonitorService {
             }
         }
     }
-
-    @Override
-    public void addAndSaveMonitorJob(Monitor monitor, List<Param> params, String collector, SdMonitorParam sdMonitorParam, GrafanaDashboard grafanaDashboard) {
-        // Apply for monitor id
-        long monitorId = SnowFlakeIdGenerator.generateId();
-        Map<String, String> labels = monitor.getLabels();
-        if (labels == null) {
-            labels = new HashMap<>(8);
-            monitor.setLabels(labels);
-        }
-        MonitorBind monitorBind = null;
-        // Construct the collection task Job entity
-        Job appDefine = appService.getAppDefine(monitor.getApp());
-        if (Objects.nonNull(sdMonitorParam)) {
-            monitorBind = Objects.isNull(sdMonitorParam.getSdParam())
-                    ? SdMonitorOperator.buildSdSubMonitorBind(sdMonitorParam, monitorId, labels)
-                    : SdMonitorOperator.buildSdMainMonitorBind(sdMonitorParam, monitorId);
-
-            appDefine = SdMonitorOperator.constructSdJobAndTag(sdMonitorParam, labels, appDefine);
-        }
-        if (CommonConstants.PROMETHEUS.equals(monitor.getApp())) {
-            appDefine.setApp(CommonConstants.PROMETHEUS_APP_PREFIX + monitor.getName());
-        }
-        appDefine.setMonitorId(monitorId);
-        appDefine.setDefaultInterval(monitor.getIntervals());
-        appDefine.setCyclic(true);
-        appDefine.setTimestamp(System.currentTimeMillis());
-        Map<String, String> metadata = Map.of(CommonConstants.LABEL_INSTANCE_NAME, monitor.getName(), 
-                CommonConstants.LABEL_INSTANCE_HOST, monitor.getHost());
-        appDefine.setMetadata(metadata);
-        appDefine.setLabels(monitor.getLabels());
-        appDefine.setAnnotations(monitor.getAnnotations());
-        resetMetricsCommonField(monitor, appDefine, sdMonitorParam);
-
-        List<Configmap> configmaps = params.stream().map(param -> {
-            param.setMonitorId(monitorId);
-            return new Configmap(param.getField(), param.getParamValue(), param.getType());
-        }).collect(Collectors.toList());
-        appDefine.setConfigmap(configmaps);
-
-        long jobId = collector == null ? collectJobScheduling.addAsyncCollectJob(appDefine, null) :
-                collectJobScheduling.addAsyncCollectJob(appDefine, collector);
-
-        try {
-            detectMonitor(monitor, params, collector);
-        } catch (Exception ignored) {
-        }
-
-        try {
-            if (collector != null) {
-                CollectorMonitorBind collectorMonitorBind = CollectorMonitorBind.builder()
-                        .collector(collector)
-                        .monitorId(monitorId)
-                        .build();
-                collectorMonitorBindDao.save(collectorMonitorBind);
-            }
-            monitor.setId(monitorId);
-            monitor.setJobId(jobId);
-            // create grafana dashboard
-            if (monitor.getApp().equals(CommonConstants.PROMETHEUS) && grafanaDashboard != null && grafanaDashboard.isEnabled()) {
-                dashboardService.createOrUpdateDashboard(grafanaDashboard.getTemplate(), monitorId);
-            }
-            monitorDao.save(monitor);
-            if (Objects.nonNull(monitorBind)) {
-                monitorBindDao.save(monitorBind);
-            }
-            paramDao.saveAll(params);
-        } catch (Exception e) {
-            log.error("Error while adding monitor: {}", e.getMessage(), e);
-            collectJobScheduling.cancelAsyncCollectJob(jobId);
-            throw new MonitorDatabaseException(e.getMessage());
-        }
-    }
-
+    
     @Override
     public Monitor getMonitor(Long monitorId) {
         return monitorDao.findById(monitorId).orElse(null);
@@ -916,73 +832,69 @@ public class MonitorServiceImpl implements MonitorService {
         return monitorDao.findMonitorsByAppEquals(app);
     }
 
-    private void resetMetricsCommonField(Monitor monitor, Job appDefine, SdMonitorParam sdMonitorParam) {
-        if (Objects.isNull(sdMonitorParam)
-                || org.apache.commons.lang3.StringUtils.isAnyBlank(sdMonitorParam.getDetectedHost(), sdMonitorParam.getDetectedPort())) {
-            return;
+    @Override
+    @Transactional(rollbackFor = Exception.class)
+    public void copyMonitor(Long id) {
+        // Get the source monitor information
+        Optional<Monitor> monitorOptional = monitorDao.findById(id);
+        if (monitorOptional.isEmpty()) {
+            throw new IllegalArgumentException("Monitor not found: " + id);
         }
-
-        for (Metrics metric : appDefine.getMetrics()) {
-            Arrays.stream(metric.getClass().getDeclaredFields())
-                    .filter(field -> metric.getProtocol().equalsIgnoreCase(field.getName()))
-                    .findFirst()
-                    .ifPresent(field -> {
-                        field.setAccessible(true);
-                        final Object obj;
-                        try {
-                            obj = field.get(metric);
-                            if (obj instanceof CommonRequestProtocol protocol) {
-                                protocol.setHost(sdMonitorParam.getDetectedHost());
-                                protocol.setPort(sdMonitorParam.getDetectedPort());
-                            }
-                        } catch (IllegalAccessException exception) {
-                            log.warn("Not such field {}", field.getName());
-                        }
-                    });
+        Monitor sourceMonitor = monitorOptional.get();
+        // Get the parameters of source monitor
+        List<Param> sourceParams = paramDao.findParamsByMonitorId(id);
+        // Create new monitor object
+        Monitor newMonitor = new Monitor();
+        // Copy basic properties, exclude ID, jobId and status
+        BeanUtils.copyProperties(sourceMonitor, newMonitor, "id", "jobId", "status");
+        // Set new name
+        newMonitor.setName(sourceMonitor.getName() + "_copy");
+        // Set initial status
+        newMonitor.setStatus(CommonConstants.MONITOR_UP_CODE);
+        // Set create and update time
+        newMonitor.setGmtCreate(LocalDateTime.now());
+        newMonitor.setGmtUpdate(LocalDateTime.now());
+        // Copy parameters
+        List<Param> newParams = new ArrayList<>();
+        if (!sourceParams.isEmpty()) {
+            for (Param sourceParam : sourceParams) {
+                Param newParam = new Param();
+                BeanUtils.copyProperties(sourceParam, newParam, "id");
+                newParam.setMonitorId(newMonitor.getId());
+                newParams.add(newParam);
+            }
         }
-
-        monitor.setHost(sdMonitorParam.getDetectedHost());
-        Map<String, String> labels = monitor.getLabels();
-        if (labels == null) {
-            labels = new HashMap<>(8);
-            monitor.setLabels(labels);
-        }
-        labels.put(CommonConstants.TAG_MONITOR_HOST, sdMonitorParam.getDetectedHost());
-        monitor.setName(monitor.getApp().toUpperCase() + CommonConstants.LOCALE_SEPARATOR + sdMonitorParam.getDetectedHost()
-                + CommonConstants.LOCALE_SEPARATOR + SnowFlakeIdGenerator.generateId());
+        addMonitor(newMonitor, newParams, null, null);
     }
 
-    private void copyMonitor(Monitor monitor, List<Param> params) {
-        monitor.setName(String.format("%s - copy", monitor.getName()));
-        addMonitor(monitor, params, null, null);
-    }
 
-    private void collectOneTimeSdData(Monitor monitor, String collector, Param sdParam) {
+    private void detectSdMonitor(Monitor monitor, List<Param> params, String collector) {
         Long monitorId = monitor.getId();
         if (monitorId == null || monitorId == 0) {
             monitorId = MONITOR_ID_TMP;
         }
-        Job appDefine = appService.getAppDefine(monitor.getApp());
-        if (CommonConstants.PROMETHEUS.equals(monitor.getApp())) {
-            appDefine.setApp(CommonConstants.PROMETHEUS_APP_PREFIX + monitor.getName());
+        if (monitor.getScrape() == null || params == null || params.isEmpty()) {
+            throw new IllegalArgumentException("scrape params is null or empty!");
         }
+        Job appDefine = appService.getAppDefine(monitor.getScrape());
         appDefine.setMonitorId(monitorId);
         appDefine.setCyclic(false);
         appDefine.setTimestamp(System.currentTimeMillis());
-        Map<String, String> metadata = Map.of(CommonConstants.LABEL_INSTANCE_NAME, monitor.getName(),
-                CommonConstants.LABEL_INSTANCE_HOST, monitor.getHost());
+        Map<String, String> metadata = Map.of(CommonConstants.LABEL_INSTANCE_NAME, monitor.getName());
         appDefine.setMetadata(metadata);
         appDefine.setLabels(monitor.getLabels());
         appDefine.setAnnotations(monitor.getAnnotations());
-        final Job sdJob = SdMonitorOperator.constructSdJob(appDefine, sdParam);
+        List<Configmap> configmaps = params.stream().map(param ->
+                new Configmap(param.getField(), param.getParamValue(), param.getType())).collect(Collectors.toList());
+        appDefine.setConfigmap(configmaps);
+        appDefine.setSd(true);
         List<CollectRep.MetricsData> collectRep;
         if (collector != null) {
-            collectRep = collectJobScheduling.collectSyncJobData(sdJob, collector);
+            collectRep = collectJobScheduling.collectSyncJobData(appDefine, collector);
         } else {
-            collectRep = collectJobScheduling.collectSyncJobData(sdJob);
+            collectRep = collectJobScheduling.collectSyncJobData(appDefine);
         }
         monitor.setStatus(CommonConstants.MONITOR_UP_CODE);
-
         // If the detection result fails, a detection exception is thrown
         if (collectRep == null || collectRep.isEmpty()) {
             monitor.setStatus(CommonConstants.MONITOR_DOWN_CODE);
@@ -1038,95 +950,4 @@ public class MonitorServiceImpl implements MonitorService {
         }
         collectRep.forEach(CollectRep.MetricsData::close);
     }
-
-    @Override
-    @Transactional(rollbackFor = Exception.class)
-    public void copyMonitor(Long id) {
-        // Get the source monitor information
-        Optional<Monitor> monitorOptional = monitorDao.findById(id);
-        if (monitorOptional.isEmpty()) {
-            throw new IllegalArgumentException("Monitor not found: " + id);
-        }
-        Monitor sourceMonitor = monitorOptional.get();
-
-        // Get the parameters of source monitor
-        List<Param> sourceParams = paramDao.findParamsByMonitorId(id);
-
-        // Create new monitor object
-        Monitor newMonitor = new Monitor();
-        // Copy basic properties, exclude ID, jobId and status
-        BeanUtils.copyProperties(sourceMonitor, newMonitor, "id", "jobId", "status");
-        // Set new name
-        newMonitor.setName(sourceMonitor.getName() + "_copy");
-        // Set initial status
-        newMonitor.setStatus(CommonConstants.MONITOR_UP_CODE);
-        // Set create and update time
-        newMonitor.setGmtCreate(LocalDateTime.now());
-        newMonitor.setGmtUpdate(LocalDateTime.now());
-        // Generate new ID using snowflake algorithm
-        newMonitor.setId(SnowFlakeIdGenerator.generateId());
-        // Save new monitor
-        newMonitor = monitorDao.save(newMonitor);
-
-        // Ensure ID is set
-        if (newMonitor.getId() == null) {
-            throw new RuntimeException("Failed to generate monitor ID");
-        }
-
-        // Copy parameters
-        if (!sourceParams.isEmpty()) {
-            List<Param> newParams = new ArrayList<>();
-            for (Param sourceParam : sourceParams) {
-                Param newParam = new Param();
-                BeanUtils.copyProperties(sourceParam, newParam, "id");
-                newParam.setMonitorId(newMonitor.getId());
-                newParams.add(newParam);
-            }
-            paramDao.saveAll(newParams);
-        }
-
-        try {
-            // Build collect job
-            Job appDefine = appService.getAppDefine(newMonitor.getApp());
-            if (CommonConstants.PROMETHEUS.equals(newMonitor.getApp())) {
-                appDefine.setApp(CommonConstants.PROMETHEUS_APP_PREFIX + newMonitor.getName());
-            }
-            // Ensure using correct monitor ID
-            appDefine.setMonitorId(newMonitor.getId());
-            appDefine.setDefaultInterval(newMonitor.getIntervals());
-            appDefine.setCyclic(true);
-            appDefine.setTimestamp(System.currentTimeMillis());
-            Map<String, String> metadata = Map.of(CommonConstants.LABEL_INSTANCE_NAME, newMonitor.getName(),
-                    CommonConstants.LABEL_INSTANCE_HOST, newMonitor.getHost());
-            appDefine.setMetadata(metadata);
-            appDefine.setLabels(newMonitor.getLabels());
-            appDefine.setAnnotations(newMonitor.getAnnotations());
-            List<Configmap> configmaps = sourceParams.stream()
-                    .map(param -> new Configmap(param.getField(), param.getParamValue(), param.getType()))
-                    .collect(Collectors.toList());
-            appDefine.setConfigmap(configmaps);
-
-            // Get collector configuration from source monitor
-            Optional<CollectorMonitorBind> bindOptional =
-                    collectorMonitorBindDao.findCollectorMonitorBindByMonitorId(sourceMonitor.getId());
-            String collector = bindOptional.map(CollectorMonitorBind::getCollector).orElse(null);
-
-            // Dispatch collect job
-            long jobId = collectJobScheduling.addAsyncCollectJob(appDefine, collector);
-            newMonitor.setJobId(jobId);
-            monitorDao.save(newMonitor);
-
-            // Copy collector binding if exists
-            if (collector != null) {
-                CollectorMonitorBind newBind = CollectorMonitorBind.builder()
-                        .collector(collector)
-                        .monitorId(newMonitor.getId())
-                        .build();
-                collectorMonitorBindDao.save(newBind);
-            }
-        } catch (Exception e) {
-            log.error("Create collect job error: {}", e.getMessage(), e);
-            throw new RuntimeException("Create collect job failed: " + e.getMessage());
-        }
-    }
 }
