@@ -18,14 +18,23 @@
  */
 
 import { AlibabaSmsConfig } from './AlibabaSmsConfig';
+import { AwsSmsConfig } from './AwsSmsConfig';
+import { SmslocalSmsConfig } from './SmslocalSmsConfig';
 import { TencentSmsConfig } from './TencentSmsConfig';
+import { TwilioSmsConfig } from './TwilioSmsConfig';
+import { UniSmsConfig } from './UniSmsConfig';
+import { SmsType } from './enums/sms-type.enum';
 
 export class SmsNoticeSender {
   id!: number;
-  type!: string;
-  tencent!: TencentSmsConfig;
-  alibaba!: AlibabaSmsConfig;
-  enable!: boolean;
+  type: SmsType = SmsType.TENCENT;
+  tencent: TencentSmsConfig = new TencentSmsConfig();
+  alibaba: AlibabaSmsConfig = new AlibabaSmsConfig();
+  unisms: UniSmsConfig = new UniSmsConfig();
+  smslocal: SmslocalSmsConfig = new SmslocalSmsConfig();
+  aws: AwsSmsConfig = new AwsSmsConfig();
+  twilio: TwilioSmsConfig = new TwilioSmsConfig();
+  enable: boolean = false;
   creator!: string;
   modifier!: string;
   gmtCreate!: number;
