@@ -23,7 +23,7 @@ import { ALAIN_I18N_TOKEN } from '@delon/theme';
 import { NzModalService } from 'ng-zorro-antd/modal';
 import { NzNotificationService } from 'ng-zorro-antd/notification';
 import { NzTableQueryParams } from 'ng-zorro-antd/table';
-import { TransferChange } from 'ng-zorro-antd/transfer';
+import { TransferChange, TransferSelectChange, TransferStat } from 'ng-zorro-antd/transfer';
 import { NzFormatEmitEvent, NzTreeNode, NzTreeNodeOptions } from 'ng-zorro-antd/tree';
 import { Subject } from 'rxjs';
 import { finalize, debounceTime, distinctUntilChanged } from 'rxjs/operators';
@@ -66,7 +66,6 @@ export class BulletinComponent implements OnInit, OnDestroy {
   checkedNodeList: NzTreeNode[] = [];
   monitors: Monitor[] = [];
   metrics = new Set<string>();
-  tempMetrics = new Set<string>();
   fields: Fields = {};
   pageIndex: number = 1;
   pageSize: number = 8;
@@ -77,6 +76,7 @@ export class BulletinComponent implements OnInit, OnDestroy {
   filterLabels: Record<string, string> = {};
   filteredMonitors: Monitor[] = [];
   private filterSubject = new Subject<string>(); //filter logic debouncing
+  currentStat: TransferStat | null = null; //transfer component status
 
   ngOnInit() {
     this.loadTabs();
@@ -134,7 +134,6 @@ export class BulletinComponent implements OnInit, OnDestroy {
     if (this.currentBulletin) {
       this.define = this.currentBulletin;
       this.onAppChange(this.define.app);
-      // this.tempMetrics.add(...this.define.fields.keys());
       this.isManageModalAdd = false;
       this.isManageModalVisible = true;
       this.isManageModalOkLoading = false;
@@ -370,6 +369,42 @@ export class BulletinComponent implements OnInit, OnDestroy {
     return tree;
   }
 
+  updateTransferStat(stat: TransferStat): boolean {
+    this.currentStat = stat;
+    // stat.shownCount = 33;
+    return true;
+  }
+
+  private collectLeafNodes(nodes: NzTreeNodeOptions[], results: NzTreeNodeOptions[]): void {
+    nodes.forEach(node => {
+      if (node.isLeaf && !node.disabled) {
+        results.push(node);
+      }
+      if (node.children) {
+        this.collectLeafNodes(node.children, results);
+      }
+    });
+  }
+
+  onSelectChange(event: TransferSelectChange): void {
+    if (event.direction === 'left' && event.checked && this.currentStat?.checkAll) {
+      const allLeafNodes: NzTreeNodeOptions[] = [];
+      this.collectLeafNodes(this.treeNodes, allLeafNodes);
+
+      allLeafNodes.forEach(node => {
+        const existing = this.checkedNodeList.find(n => n.origin.id === node.id);
+        if (!existing) {
+          const treeNode = new NzTreeNode(node);
+          treeNode.isChecked = true;
+          this.checkedNodeList.push(treeNode);
+        }
+      });
+    }
+    if (event.direction === 'left' && !event.checked && this.currentStat?.checkAll === false) {
+      this.checkedNodeList = [];
+    }
+  }
+
   treeCheckBoxChange(event: NzFormatEmitEvent, onItemSelect: (item: NzTreeNodeOptions) => void): void {
     this.checkBoxChange(event.node!, onItemSelect);
   }
@@ -394,37 +429,47 @@ export class BulletinComponent implements OnInit, OnDestroy {
   transferChange(ret: TransferChange): void {
     // add
     if (ret.to === 'right') {
-      ret.list.forEach(node => {
-        node.isDisabled = true;
-        node.isChecked = true;
-        this.tempMetrics.add(node.key);
-
-        if (!this.fields[node.key]) {
-          this.fields[node.key] = [];
-        }
-        if (!this.fields[node.key].includes(node.value)) {
-          this.fields[node.key].push(node.value);
+      this.checkedNodeList.forEach(node => {
+        // Check if each transferred node is in the left selected nodes
+        const item = ret.list.find(w => w.value === node.origin.value);
+        if (item) {
+          // If it exists, disable the node and set it to checked
+          node.isDisabled = true;
+          node.isChecked = true;
+          // If the key does not exist, create an empty array
+          if (!this.fields[item.key]) {
+            this.fields[item.key] = [];
+          }
+          // If the key exists but the value is not saved, add it to the value array
+          if (!this.fields[item.key].includes(item.value)) {
+            this.fields[item.key].push(item.value);
+          }
         }
       });
     }
     // delete
     else if (ret.to === 'left') {
-      ret.list.forEach(node => {
-        node.isDisabled = false;
-        node.isChecked = false;
-        this.tempMetrics.delete(node.key);
-
-        if (this.fields[node.key]) {
-          const index = this.fields[node.key].indexOf(node.value);
-          if (index > -1) {
-            this.fields[node.key].splice(index, 1);
-          }
-          // 如果该 key 下的数组为空，则删除该 key
-          if (this.fields[node.key].length === 0) {
-            delete this.fields[node.key];
+      this.checkedNodeList.forEach(node => {
+        // Check if each transferred node is in the left selected nodes
+        const item = ret.list.find(w => w.value === node.origin.value);
+        if (item) {
+          // If it exists, enable the node and set it to unchecked
+          node.isDisabled = false;
+          node.isChecked = false;
+          // If the key exists, delete the value
+          if (this.fields[item.key]) {
+            const index = this.fields[item.key].indexOf(item.value);
+            if (index > -1) {
+              this.fields[item.key].splice(index, 1);
+            }
+            // If the array under this key is empty, delete the key
+            if (this.fields[item.key].length === 0) {
+              delete this.fields[item.key];
+            }
           }
         }
       });
+      this.checkedNodeList = this.checkedNodeList.filter(item => item.isChecked);
     }
   }
 
