@@ -58,7 +58,7 @@ export class SystemConfigComponent implements OnInit {
         if (message.code === 0) {
           if (message.data) {
             this.config = message.data;
-            this.changeTheme(this.config.theme); // update theme after config is loaded
+            this.config.theme = this.themeService.getTheme() || 'default';
           } else {
             this.config = new SystemConfig();
           }
@@ -94,6 +94,7 @@ export class SystemConfigComponent implements OnInit {
             this.i18nSvc.loadLangData(language).subscribe(res => {
               this.i18nSvc.use(language, res);
               this.settings.setLayout('lang', language);
+              this.themeService.setTheme(this.config.theme);
               setTimeout(() => this.doc.location.reload());
             });
           } else {
@@ -105,8 +106,4 @@ export class SystemConfigComponent implements OnInit {
         }
       );
   }
-
-  changeTheme(theme: string): void {
-    this.themeService.changeTheme(theme);
-  }
 }
