@@ -26,13 +26,11 @@ import { NzNotificationService } from 'ng-zorro-antd/notification';
 import { switchMap } from 'rxjs';
 
 import { Message } from '../../../pojo/Message';
-import { TagItem } from '../../../pojo/NoticeRule';
 import { StatusPageComponent } from '../../../pojo/StatusPageComponent';
 import { StatusPageIncident } from '../../../pojo/StatusPageIncident';
 import { StatusPageIncidentContent } from '../../../pojo/StatusPageIncidentContent';
 import { StatusPageOrg } from '../../../pojo/StatusPageOrg';
 import { StatusPageService } from '../../../service/status-page.service';
-import { TagService } from '../../../service/tag.service';
 
 @Component({
   selector: 'app-status',
@@ -44,7 +42,6 @@ export class StatusComponent implements OnInit {
     private notifySvc: NzNotificationService,
     private modal: NzModalService,
     private statusPageService: StatusPageService,
-    private tagService: TagService,
     @Inject(ALAIN_I18N_TOKEN) private i18nSvc: I18NService
   ) {}
 
@@ -70,8 +67,6 @@ export class StatusComponent implements OnInit {
   isIncidentModalAdd: boolean = true;
 
   search!: string;
-  tagsOption: any[] = [];
-  matchTag: string = '';
 
   ngOnInit(): void {
     this.loadStatusPageConfig();
@@ -182,7 +177,6 @@ export class StatusComponent implements OnInit {
   onNewStatusComponent() {
     this.isComponentModalAdd = true;
     this.currentStatusComponent = new StatusPageComponent();
-    this.matchTag = '';
     this.currentComponentVisible = true;
   }
 
@@ -220,13 +214,6 @@ export class StatusComponent implements OnInit {
   onEditOneComponent(data: StatusPageComponent) {
     this.isComponentModalAdd = false;
     this.currentStatusComponent = { ...data };
-    if (this.currentStatusComponent.tag != undefined) {
-      this.matchTag = this.sliceTagName(this.currentStatusComponent.tag);
-      this.tagsOption.push({
-        value: this.matchTag,
-        label: this.matchTag
-      });
-    }
     this.currentComponentVisible = true;
   }
 
@@ -304,17 +291,6 @@ export class StatusComponent implements OnInit {
       });
       return;
     }
-    if (this.matchTag != undefined && this.matchTag.trim() != '') {
-      let tmp: string[] = this.matchTag.split(':');
-      let tagItem = new TagItem();
-      if (tmp.length == 1) {
-        tagItem.name = tmp[0];
-      } else if (tmp.length == 2) {
-        tagItem.name = tmp[0];
-        tagItem.value = tmp[1];
-      }
-      this.currentStatusComponent.tag = tagItem;
-    }
     if (this.statusOrg.id == undefined) {
       this.notifySvc.warning(this.i18nSvc.fanyi('status.component.notify.need-org'), '');
       return;
@@ -479,36 +455,6 @@ export class StatusComponent implements OnInit {
     });
   }
 
-  loadTagsOption() {
-    let tagsInit$ = this.tagService.loadTags(undefined, undefined, 0, 1000).subscribe(
-      message => {
-        if (message.code === 0) {
-          let page = message.data;
-          this.tagsOption = [];
-          if (page.content != undefined) {
-            page.content.forEach(item => {
-              let tag = `${item.name}`;
-              if (item.tagValue != undefined) {
-                tag = `${tag}:${item.tagValue}`;
-              }
-              this.tagsOption.push({
-                value: tag,
-                label: tag
-              });
-            });
-          }
-        } else {
-          console.warn(message.msg);
-        }
-        tagsInit$.unsubscribe();
-      },
-      error => {
-        tagsInit$.unsubscribe();
-        console.error(error.msg);
-      }
-    );
-  }
-
   getLatestIncidentContentMsg(incidents: StatusPageIncidentContent[]): string {
     if (incidents == undefined || incidents.length == 0) {
       return '';
@@ -533,14 +479,19 @@ export class StatusComponent implements OnInit {
     }
   }
 
-  sliceTagName(tag: TagItem): string {
-    if (tag == undefined) {
-      return '';
-    }
-    if (tag.value != undefined && tag.value.trim() != '') {
-      return `${tag.name}:${tag.value}`;
-    } else {
-      return tag.name;
+  getLabelColor(key: string): string {
+    const colors = ['blue', 'green', 'orange', 'purple', 'cyan'];
+    const index = Math.abs(this.hashString(key)) % colors.length;
+    return colors[index];
+  }
+
+  private hashString(str: string): number {
+    let hash = 0;
+    for (let i = 0; i < str.length; i++) {
+      const char = str.charCodeAt(i);
+      hash = (hash << 5) - hash + char;
+      hash = hash & hash;
     }
+    return hash;
   }
 }
