@@ -48,14 +48,6 @@ export class MonitorService {
     return this.http.put<Message<any>>(monitor_uri, body);
   }
 
-  public getMonitorByApp(app: string): Observable<Message<any>> {
-    return this.http.get<Message<any>>(`${monitor_uri}/metric/${app}`);
-  }
-
-  public deleteMonitor(monitorId: number): Observable<Message<any>> {
-    return this.http.delete<Message<any>>(`${monitor_uri}/${monitorId}`);
-  }
-
   public deleteMonitors(monitorIds: Set<number>): Observable<Message<any>> {
     let httpParams = new HttpParams();
     monitorIds.forEach(monitorId => {
@@ -117,8 +109,8 @@ export class MonitorService {
 
   public searchMonitors(
     app: string | undefined,
-    tag: string | undefined,
-    searchValue: string,
+    labels: string | undefined,
+    search: string,
     status: number,
     pageIndex: number,
     pageSize: number,
@@ -133,8 +125,8 @@ export class MonitorService {
       pageIndex: pageIndex,
       pageSize: pageSize
     });
-    if (tag != undefined) {
-      httpParams = httpParams.append('tag', tag);
+    if (labels != undefined) {
+      httpParams = httpParams.append('labels', labels);
     }
     if (status != undefined && status != 9) {
       httpParams = httpParams.append('status', status);
@@ -148,9 +140,8 @@ export class MonitorService {
         order: sortOrder == 'ascend' ? 'asc' : 'desc'
       });
     }
-    if (searchValue != undefined && searchValue != '' && searchValue.trim() != '') {
-      httpParams = httpParams.append('name', searchValue);
-      httpParams = httpParams.append('host', searchValue);
+    if (search != undefined && search != '' && search.trim() != '') {
+      httpParams = httpParams.append('search', search);
     }
     const options = { params: httpParams };
     return this.http.get<Message<Page<Monitor>>>(monitors_uri, options);
@@ -175,7 +166,7 @@ export class MonitorService {
       interval: interval
     });
     const options = { params: httpParams };
-    return this.http.get<Message<any>>(`/monitor/${monitorId}/metric/${metricFull}`, options);
+    return this.http.get<Message<any>>(`${monitor_uri}/${monitorId}/metric/${metricFull}`, options);
   }
 
   public getAppsMonitorSummary(): Observable<Message<any>> {
@@ -193,4 +184,8 @@ export class MonitorService {
   public deleteGrafanaDashboard(monitorId: number): Observable<Message<any>> {
     return this.http.delete<Message<any>>(`${grafana_dashboard_uri}?monitorId=${monitorId}`);
   }
+
+  copyMonitor(id: number): Observable<any> {
+    return this.http.post<Message<any>>(`${monitor_uri}/copy/${id}`, null);
+  }
 }
